@@ -30,7 +30,9 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, ProcessMessage):
             return obj.__dict__
-        elif isinstance(obj, ProgramState):
+        elif isinstance(obj, RobotState):
+            return obj.__dict__
+        elif isinstance(obj, RobotStateChange):
             return obj.__dict__
         elif isinstance(obj, AxisAngle):
             return obj.__dict__
@@ -70,8 +72,10 @@ class JsonDecoder(json.JSONDecoder):
                 return Process(**obj)
             if '_type' in obj and obj['_type'] == 'process_message':
                 return ProcessMessage(**obj)
-            if '_type' in obj and obj['_type'] == 'program_state':
-                return ProgramState(**obj)
+            if '_type' in obj and obj['_type'] == 'robot_state':
+                return RobotState(**obj)
+            if '_type' in obj and obj['_type'] == 'robot_state_change':
+                return RobotStateChange(**obj)
             if '_type' in obj and obj['_type'] == 'axis_angle':
                 return AxisAngle(**obj)
         return obj
