@@ -20,3 +20,9 @@ def get_json_format() -> logging.Formatter:
         "{'time':'%(asctime)s', 'name': '%(name)s', 'func': '%(funcName)s', 'level': '%(levelname)s', "
         "'message': '%(message)s'}"
     )
+
+
+def json_log_handler(filename: str) -> logging.Handler:
+    file_handler = logging.FileHandler(filename)
+    file_handler.setFormatter(get_json_format())
+    return file_handler
