@@ -5,4 +5,4 @@ from holour.msg.script import Script, WaypointConfig
 from holour.msg.task import Task, TaskMessage
 from holour.msg.product import Product
 from holour.msg.process import Process, ProcessMessage
-from holour.msg.robot import ProgramState
+from holour.msg.robot import RobotState, RobotStateChange
